#include "carmainwindow.h"
#include "ui_carmainwindow.h"
#include "stringlistmodel.h"
#include <QStandardItemModel>
#include <QStringList>
#include <QString>

/**
  *Constructor of this class.
  *@param QWidget pointer to parent object. By default the value is NULL.
  */
CarMainWindow::CarMainWindow(QWidget *parent):QMainWindow(parent), ui(new Ui::CarMainWindow)
{
    ui->setupUi(this);
    result = new ResultDialog();
    measure = new MeasureDialog();

    initUnitCompoBox();
    initSpeedListView();
    initCategoryCompoBox();
}

/**
  *Destructor of this class. Should be used to release all allocated resources.
  */
CarMainWindow::~CarMainWindow()
{
    delete ui;
    delete result;
    delete measure;
}

/**
  *This function is used to .
  *@param
  */
void CarMainWindow::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

/**
  *This slot function is called when ever list view is update.
  *@param QModelIndex index.
  */
void CarMainWindow::on_listView_clicked(QModelIndex index)
{
    QString str = index.data().toString();
    QStringList list = str.split("-");
    QStringList list2 = list[1].split(" ");

    ui->minLineEdit->setText(list[0]);
    ui->maxLineEdit->setText(list2[0]);
    updateUnitCompoBox(list2[1]);
}

/**
  *This slot function is called when ever auto start button clicked.
  */
void CarMainWindow::on_autoStartButton_clicked()
{
   result->show();
}

/**
  *This slot function is called when ever list view is update.
  *@param QString unit.
  */
void CarMainWindow::updateUnitCompoBox(QString unit)
{
    ui->unitComboBox->setCurrentIndex(ui->unitComboBox->findText(unit, Qt::MatchExactly));
}

/**
  *This function is used to init unit combobox.
  */
void CarMainWindow::initUnitCompoBox()
{
    units << "km/h" << "km" << "h" << "m" << "min" << "mil" << "in" << "ft" << "yrd";
    ui->unitComboBox->addItems(units);
}

/**
  *This function is used to set items to unit combobox.
  *@param QStringlist numbers
  */
void CarMainWindow::setUnitCompoBox(QStringList units)
{
    ui->unitComboBox->addItems(units);
}

/**
  *This function is used to init speed listview.
  */
void CarMainWindow::initSpeedListView()
{
    numbers << "0-100 km/h" << "0-1/4 mil" << "0-50 km" << "50-100 mil" << "0-100 m" << "0-50 ft" << "0-50 yrd" << "0-500 in";
    QAbstractItemModel *model = new StringListModel(numbers);
    ui->listView->setModel(model);
}

/**
  *This function is used to set items to speed listview.
  *@param QStringlist numbers
  */
void CarMainWindow::setSpeedListView(QStringList numbers)
{
    QAbstractItemModel *model = new StringListModel(numbers);
    ui->listView->setModel(model);
}

/**
  *This function is used to init category combobox.
  */
void CarMainWindow::initCategoryCompoBox()
{
    categories << "Top 10 1/4 mile" << "Top 10 0-100 km/h" << "Top 10 car";
    ui->comboBoxTopCategory->addItems(categories);
}

/**
  *This function is used to set items to category combobox.
  *@param QStringlist categories
  */
void CarMainWindow::setCategoryCompoBox(QStringList categories)
{
    ui->comboBoxTopCategory->addItems(categories);
}

/**
  *This slot function is called when ever categories combobox is update.
  *@param QString category
  */
void CarMainWindow::on_comboBoxTopCategory_activated(QString category)
{
    //TODO: get top list

    QStringList topList;
    topList << "1. Pertti 7,5s" << "2. Ville 10,2s";

    QAbstractItemModel *model = new StringListModel(topList);
    ui->listViewTopList->setModel(model);
}
